@@ -30,11 +30,11 @@ from .errors import (
 )
 from .response import SMTPResponse
 from .smtp import SMTP
-from .typing import SMTPStatus
+from .typing import SMTPStatus, SMTPTokenGenerator
 
 
 __title__ = "aiosmtplib"
-__version__ = "5.0.0"
+__version__ = "5.1.0"
 __author__ = "Cole Maclean"
 __license__ = "MIT"
 __copyright__ = "Copyright 2022 Cole Maclean"
@@ -43,6 +43,7 @@ __all__ = (
     "SMTP",
     "SMTPResponse",
     "SMTPStatus",
+    "SMTPTokenGenerator",
     "SMTPAuthenticationError",
     "SMTPConnectError",
     "SMTPDataError",
