@@ -11,12 +11,7 @@ import pytest
 from aiosmtplib import SMTP
 
 
-pytestmark = pytest.mark.asyncio()
-
-
-async def test_tls_context_and_cert_raises(
-    client_tls_context: ssl.SSLContext,
-) -> None:
+async def test_tls_context_and_cert_raises(client_tls_context: ssl.SSLContext) -> None:
     with pytest.raises(ValueError):
         SMTP(use_tls=True, client_cert="foo.crt", tls_context=client_tls_context)
 
@@ -31,9 +26,7 @@ async def test_tls_context_and_cert_to_connect_raises(
 
 
 async def test_tls_context_and_cert_to_starttls_raises(
-    smtp_client: SMTP,
-    smtpd_server: asyncio.AbstractServer,
-    client_tls_context: ssl.SSLContext,
+    smtp_client: SMTP, client_tls_context: ssl.SSLContext
 ) -> None:
     async with smtp_client:
         with pytest.raises(ValueError):
@@ -54,11 +47,6 @@ async def test_use_tls_and_start_tls_to_connect_raises() -> None:
         await client.connect(start_tls=True)
 
 
-async def test_socket_and_hostname_raises() -> None:
-    with pytest.raises(ValueError):
-        SMTP(hostname="example.com", sock=socket.socket(socket.AF_INET))
-
-
 async def test_socket_and_port_raises() -> None:
     with pytest.raises(ValueError):
         SMTP(port=1, sock=socket.socket(socket.AF_INET))
@@ -69,9 +57,14 @@ async def test_socket_and_socket_path_raises() -> None:
         SMTP(socket_path="/tmp/test", sock=socket.socket(socket.AF_INET))  # nosec
 
 
-async def test_hostname_and_socket_path_raises() -> None:
+async def test_tls_socket_with_no_hostname_raises() -> None:
     with pytest.raises(ValueError):
-        SMTP(hostname="example.com", socket_path="/tmp/test")  # nosec
+        SMTP(hostname=None, sock=socket.socket(socket.AF_INET), use_tls=True)  # nosec
+
+
+async def test_tls_socket_path_with_no_hostname_raises() -> None:
+    with pytest.raises(ValueError):
+        SMTP(hostname=None, socket_path="/tmp/test", use_tls=True)  # nosec
 
 
 async def test_port_and_socket_path_raises() -> None:
@@ -138,8 +131,7 @@ async def test_default_port_on_connect(
 
 
 async def test_connect_hostname_takes_precedence(
-    hostname: str,
-    smtpd_server_port: int,
+    hostname: str, smtpd_server_port: int
 ) -> None:
     client = SMTP(hostname="example.com", port=smtpd_server_port, start_tls=False)
     await client.connect(hostname=hostname)
@@ -150,8 +142,7 @@ async def test_connect_hostname_takes_precedence(
 
 
 async def test_connect_port_takes_precedence(
-    hostname: str,
-    smtpd_server_port: int,
+    hostname: str, smtpd_server_port: int
 ) -> None:
     client = SMTP(hostname=hostname, port=17, start_tls=False)
     await client.connect(port=smtpd_server_port)
@@ -162,8 +153,7 @@ async def test_connect_port_takes_precedence(
 
 
 async def test_connect_timeout_is_reverted(
-    hostname: str,
-    smtpd_server_port: int,
+    hostname: str, smtpd_server_port: int
 ) -> None:
     client = SMTP(
         hostname=hostname, port=smtpd_server_port, timeout=0.66, start_tls=False
@@ -250,9 +240,7 @@ async def test_connect_validate_certs_takes_precedence(
 
 
 async def test_connect_certificate_options_take_precedence(
-    hostname: str,
-    smtpd_server_port: int,
-    client_tls_context: ssl.SSLContext,
+    hostname: str, smtpd_server_port: int
 ) -> None:
     client = SMTP(
         hostname=hostname,
